==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/hco10.h <==
/*!================================================================
 module:        hco10.h
 
 responsible:   ThomasA
 
 special area:  OMS
 
 description:   C++ Persistent Object Interface
 
 see:
 
 copyright:     SAP AG 1998 


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/



#if !defined (__HCO10_H)
#define __HCO10_H

#include "gco001.h"
#include "gco02.h"
#include "hco18.h"

class OmsContext_co12;

externCpp
ClassInfo_co18* co10_FindClassInfo(IliveCacheSink* lcSink, const GUID guid);

externCpp
ContainerInfo_co18* co10_FindContainerInfo(IliveCacheSink* lcSink, tsp00_Uint4 containerInfo);

externCpp
ContainerInfo_co18* co10_FindContainerInfo(IliveCacheSink* lcSink, const GUID& guid, OmsSchemaHandle, OmsContainerNo);

externCpp
tsp00_Uint4 co10_GetLastDropId();

externC ProcGetInterfacePtr_co02 co10_GetProcInterface;

tsp00_Uint4 co10_chunkSize(void* p);

void co10_MarkUnloadable(OmsContext_co12* pContext);

void* co10_malloc (IliveCacheSink* lcSink, size_t size);

void co10_free(IliveCacheSink* lcSink, void* p); 

externCpp
void co10_DetachContainerInfo(IliveCacheSink*, pContainerInfo_co18);

IliveCacheSink* co10_GetLcSink();

ContainerInfo_co18* co10_RegisterContainer (IliveCacheSink* lcSink, 
                                         const GUID& guid, 
                                         const char* ClassName, 
                                         size_t PersistentSize, 
                                         size_t ObjectSize, 
                                         const GUID* pBaseClass,
                                         const tgg00_ObjColDesc &ColDesc,
                                         OmsSchemaHandle sh,
                                         OmsContainerNo cno,
                                         void* vtptr);

externCpp
void co10_ToKnlIdentifier (const char* Source, tsp00_KnlIdentifier& Dest);

#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/hco10.h <==
/*!================================================================
 module:        hco10.h
 
 responsible:   ThomasA
 
 special area:  OMS
 
 description:   C++ Persistent Object Interface
 
 see:
 
 copyright:     SAP AG 1998 


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/



#if !defined (__HCO10_H)
#define __HCO10_H

#include "gco001.h"
#include "gco02.h"
#include "hco18.h"

class OmsContext_co12;
class DbpError;
class LVC_KernelInterface;

externCpp
ClassInfo_co18* co10_FindClassInfo(IliveCacheSink* lcSink, const ClassIDRef guid);

bool co10_dumpRequested(tsp00_Int4 errorNo);

externCpp
ContainerInfo_co18* co10_FindContainerInfo(IliveCacheSink* lcSink, tsp00_Uint4 containerInfo);

externCpp
ContainerInfo_co18* co10_FindContainerInfo(IliveCacheSink* lcSink, const ClassIDRef guid, OmsSchemaHandle, OmsContainerNo);

externCpp
tsp00_Uint4 co10_GetLastDropId();

externC ProcGetInterfacePtr_co02 co10_GetProcInterface;

externCpp
ITrace_co02* co10_GetTracer();

externCpp 
bool co10_IsOmsTestLib();

tsp00_Int4 co10_clock();  // PTS 1110315

void co10_MarkUnloadable(OmsContext_co12* pContext, bool callFromDestructor);

void* co10_malloc (size_t size);

void co10_free(void* p); 

externCpp
void co10_DetachContainerInfo(IliveCacheSink*, pContainerInfo_co18);

LVC_KernelInterface* co10_GetKernelInterface();

IliveCacheSink* co10_GetLcSink();

ContainerInfo_co18* co10_RegisterContainer (IliveCacheSink* lcSink, 
                                         const ClassIDRef guid, 
                                         const char* ClassName, 
                                         size_t PersistentSize, 
                                         size_t ObjectSize, 
                                         const ClassIDPtr pBaseClass,
                                         const tgg00_ObjColDesc &ColDesc,
                                         OmsSchemaHandle sh,
                                         OmsContainerNo cno,
                                         void* vtptr,
                                         size_t arrayByteSize = 0);

externCpp
void AFX_EXT_CLASS co10_ResetOMSForSimulator();

externCpp
void co10_Signal(tsp00_TaskId TaskId, bool timeout); // PTS 1110315

externCpp
void co10_Throw(const DbpError& e);

externCpp
void co10_ToKnlIdentifier (const char* Source, tsp00_KnlIdentifier& Dest);

#endif
